@@ -61,12 +61,6 @@ autoreconf -i -v
 
 
 
-### Remove stale/backup files
-#
-rm -f config.h.in~
-
-
-
 ### Signal success and exit
 #
 echo
