@@ -49,10 +49,16 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_cmdline (char * const result, __attribute__((unused)) char const * const arg)
+int snoopy_datasource_cmdline (char * const resultBuf, size_t resultBufSize, __attribute__((unused)) char const * const arg)
 {
     const snoopy_inputdatastorage_t * snoopy_inputdatastorage;
-    size_t bytesWrittenToResult;
+    size_t bytesWrittenToResultBuf;
+
+    // Return on this impossible condition
+    // We're only adding this check here because SonarCloud is detecting a "bug" with resultBufSize=0.
+    if (resultBufSize <= 0) {
+        return 0;
+    }
 
     /* Get argument data of execv/e() call */
     snoopy_inputdatastorage = snoopy_inputdatastorage_get();
@@ -69,41 +75,41 @@ int snoopy_datasource_cmdline (char * const result, __attribute__((unused)) char
         (snoopy_inputdatastorage->argv[0] == NULL)
     ) {
         if (NULL == snoopy_inputdatastorage->filename) {
-            return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "(unknown)");
+            return snprintf(resultBuf, resultBufSize, "(unknown)");
         } else {
-            return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", snoopy_inputdatastorage->filename);
+            return snprintf(resultBuf, resultBufSize, "%s", snoopy_inputdatastorage->filename);
         }
     }
 
     // Recompose the command into a result string
-    bytesWrittenToResult = 0;
+    bytesWrittenToResultBuf = 0;
     for (int argId=0 ; snoopy_inputdatastorage->argv[argId] != NULL ; argId++) {
 
         // Add space before every non-first argument
-        if ((argId > 0) && (bytesWrittenToResult < SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE)) {
-            bytesWrittenToResult += snprintf(
-                result+bytesWrittenToResult,
-                SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE - bytesWrittenToResult,
+        if ((argId > 0) && (bytesWrittenToResultBuf < resultBufSize)) {
+            bytesWrittenToResultBuf += snprintf(
+                resultBuf + bytesWrittenToResultBuf,
+                resultBufSize - bytesWrittenToResultBuf,
                 " "
             );
         }
 
         // Copy the content
-        if (bytesWrittenToResult < SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE) {
-            bytesWrittenToResult += snprintf(
-                result+bytesWrittenToResult,
-                SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE - bytesWrittenToResult,
+        if (bytesWrittenToResultBuf < resultBufSize) {
+            bytesWrittenToResultBuf += snprintf(
+                resultBuf + bytesWrittenToResultBuf,
+                resultBufSize - bytesWrittenToResultBuf,
                 "%s", snoopy_inputdatastorage->argv[argId]
             );
         }
     }
 
     // Ensure the presence of a terminating null character
-    if (bytesWrittenToResult < SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE) {
-        result[bytesWrittenToResult] = '\0';
+    if (bytesWrittenToResultBuf < resultBufSize) {
+        resultBuf[bytesWrittenToResultBuf] = '\0';
     } else {
-        result[SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE-1] = '\0';
+        resultBuf[resultBufSize-1] = '\0';
     }
 
-    return (int) bytesWrittenToResult;
+    return (int) bytesWrittenToResultBuf;
 }
