@@ -46,7 +46,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_snoopy_literal (char * const result, char const * const arg)
+int snoopy_datasource_snoopy_literal (char * const resultBuf, size_t resultBufSize, char const * const arg)
 {
-    return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", arg);
+    return snprintf(resultBuf, resultBufSize, "%s", arg);
 }
