@@ -48,7 +48,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_uid (char * const result, __attribute__((unused)) char const * const arg)
+int snoopy_datasource_uid (char * const resultBuf, size_t resultBufSize, __attribute__((unused)) char const * const arg)
 {
-    return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%u", getuid());
+    return snprintf(resultBuf, resultBufSize, "%u", getuid());
 }
