@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/filter/exclude_spawns_of.c
  *
@@ -81,7 +81,7 @@ static char **string_to_token_array(char *str);
  * Return:
  *     SNOOPY_FILTER_PASS or SNOOPY_FILTER_DROP
  */
-int snoopy_filter_exclude_spawns_of(char *msg, char const * const arg)
+int snoopy_filter_exclude_spawns_of (char const * const arg)
 {
     char  *argDup;   // Must not alter arg
     char **losp; // List of specified programs derived from arg
@@ -263,6 +263,6 @@ static char **string_to_token_array(char *str)
         p = NULL;
     }
     token_array[token_count] = NULL;
-    return(token_array);
+    return token_array;
 }
 
