@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/filter/exclude_uid.h
  *
@@ -25,4 +25,4 @@
 /*
  * SNOOPY FILTER: exclude_uid
  */
-int snoopy_filter_exclude_uid (char *msg, char const * const arg);
+int snoopy_filter_exclude_uid (char const * const arg);
