@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/noop.c
  *
@@ -44,7 +44,7 @@
  * Return:
  *     SNOOPY_FILTER_PASS
  */
-int snoopy_filter_noop(char *msg, char const * const arg)
+int snoopy_filter_noop(__attribute__((unused)) char const * const arg)
 {
     return SNOOPY_FILTER_PASS;
 }
