@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/noop.h
  *
@@ -25,4 +25,4 @@
 /*
  * SNOOPY FILTER: noop
  */
-int snoopy_filter_noop(char *msg, char const * const arg);
+int snoopy_filter_noop (char const * const arg);
