@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/filter/only_root.c
  *
@@ -48,7 +48,7 @@
  * Return:
  *     SNOOPY_FILTER_PASS or SNOOPY_FILTER_DROP
  */
-int snoopy_filter_only_root (char *msg, char const * const arg)
+int snoopy_filter_only_root (__attribute__((unused)) char const * const arg)
 {
     if (0 == getuid()) {
         return SNOOPY_FILTER_PASS;
