@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/filter/only_root.h
  *
@@ -25,4 +25,4 @@
 /*
  * SNOOPY FILTER: only_root
  */
-int snoopy_filter_only_root (char *msg, char const * const arg);
+int snoopy_filter_only_root (char const * const arg);
