@@ -1,6 +1,6 @@
 
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/tty.h
  *
@@ -34,4 +34,4 @@
 /*
  * SNOOPY FILTER: only_tty
  */
-int snoopy_filter_only_tty(char *msg, char const * const arg);
+int snoopy_filter_only_tty (char const * const arg);
