@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/filter/only_uid.h
  *
@@ -25,4 +25,4 @@
 /*
  * SNOOPY FILTER: only_uid
  */
-int snoopy_filter_only_uid (char *msg, char const * const arg);
+int snoopy_filter_only_uid (char const * const arg);
