@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: inputdatastorage.c
  *
@@ -32,6 +32,8 @@
 #include "tsrm.h"
 #endif
 
+#include <stddef.h>
+
 
 
 /*
