@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/output/devttyoutput.h
  *
@@ -25,4 +25,4 @@
 /*
  * SNOOPY OUTPUT: directly to /dev/tty
  */
-int snoopy_output_devttyoutput (char const * const logMessage, int errorOrMessage, char const * const arg);
+int snoopy_output_devttyoutput (char const * const logMessage, char const * const arg);
