@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/output/stdoutoutput.c
  *
@@ -39,13 +39,12 @@
  *
  * Params:
  *     message:    message to send
- *     errOrMsg:   is message and error message or ordinary Snoopy log message
  *     arg:        output argument(s)
  *
  * Return:
  *     int:        See snoopy.h (SNOOPY_OUTPUT_*) for details.
  */
-int snoopy_output_stdoutoutput (char const * const logMessage, int errorOrMessage, char const * const arg)
+int snoopy_output_stdoutoutput (char const * const logMessage, __attribute__((unused)) char const * const arg)
 {
     return fprintf(stdout, "%s\n", logMessage);
 }
