@@ -13,7 +13,7 @@ set -u
 ### Get data
 #
 export SNOOPY_TEST_DATASOURCE_ENV_SET="asdf"
-VAL_SNOOPY=`$SNOOPY_TEST_DATASOURCE env "SNOOPY_TEST_DATASOURCE_ENV_SET"`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI run datasource env "SNOOPY_TEST_DATASOURCE_ENV_SET"`
 VAL_REAL="$SNOOPY_TEST_DATASOURCE_ENV_SET"
 
 
