@@ -12,8 +12,8 @@ set -u
 
 ### Get data
 #
-VAL_SNOOPY=`$SNOOPY_TEST_DATASOURCE group`
-VAL_REAL=`id -a | grep -Eo 'gid=[0-9]+[(][^)]+[)]' | grep -Eo '[(][^)]+[)]' | grep -Eo '[^()]+'`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI run datasource group`
+VAL_REAL=`id -g -n`
 
 
 
