@@ -12,7 +12,7 @@ set -u
 
 ### Get data
 #
-VAL_SNOOPY=`$SNOOPY_TEST_DATASOURCE timestamp`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI run datasource timestamp`
 snoopy_testRun_info "Snoopy value: $VAL_SNOOPY"
 VAL_REAL=`date +"%s"`
 snoopy_testRun_info "Real value:   $VAL_REAL"
