@@ -17,7 +17,7 @@ set -u
 #
 PARENT_PROC_NAME="bash"
 . /etc/os-release
-if [[ $ID =~ ^(arch|centos|opensuse) ]]; then
+if [[ $ID =~ ^(alpine|arch|almalinux|centos|fedora|rhel|opensuse) ]]; then
     PARENT_PROC_NAME="sh"
 fi
 
@@ -25,7 +25,7 @@ fi
 
 ### Get data
 #
-if ! $SNOOPY_TEST_FILTER   "msg"   "exclude_spawns_of"   "$PARENT_PROC_NAME,aaaa,bbbb" > /dev/null; then
+if ! $SNOOPY_TEST_CLI run filter   "exclude_spawns_of"   "$PARENT_PROC_NAME,aaaa,bbbb" > /dev/null; then
     snoopy_testResult_pass
 else
     snoopy_testResult_fail "Message passed through when it shouldn't."
