@@ -12,10 +12,10 @@ set -u
 
 ### Get data
 #
-MY_UID=`$SNOOPY_TEST_DATASOURCE uid`
+MY_UID=`$SNOOPY_TEST_CLI run datasource uid`
 MY_UID_PLUS_1=`expr $MY_UID + 1`
 
-if ! $SNOOPY_TEST_FILTER   "msg"   "only_uid"   "$MY_UID_PLUS_1" > /dev/null; then
+if ! $SNOOPY_TEST_CLI run filter   "only_uid"   "$MY_UID_PLUS_1" > /dev/null; then
     snoopy_testResult_pass
 else
     snoopy_testResult_fail "My UID: $MY_UID"
