@@ -13,8 +13,8 @@ set -u
 ### Get data
 #
 DATASOURCE="snoopy_version"
-VAL_SNOOPY=`$SNOOPY_TEST_MESSAGE_FORMAT "%{$DATASOURCE}"`
-VAL_REAL=`$SNOOPY_TEST_DATASOURCE "$DATASOURCE"`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI run messageformat "%{$DATASOURCE}"`
+VAL_REAL=`$SNOOPY_TEST_CLI run datasource "$DATASOURCE"`
 
 
 
